@@ -17,7 +17,7 @@ from jaaql.utilities.utils import get_jaaql_root, get_base_url
 from jaaql.db.db_utils import create_interface, jaaql__encrypt, create_interface_for_db
 from jaaql.db.db_utils_no_circ import submit, get_required_db, objectify
 from jaaql.utilities import crypt_utils
-from jaaql.utilities.utils_no_project_imports import get_cookie_attrs, COOKIE_JAAQL_AUTH, COOKIE_ATTR_EXPIRES
+from jaaql.utilities.utils_no_project_imports import get_cookie_attrs, COOKIE_JAAQL_AUTH, COOKIE_ATTR_EXPIRES, time_delta_ms
 from jaaql.mvc.response import *
 import threading
 from datetime import datetime, timedelta
@@ -449,11 +449,14 @@ WHERE
             if len(override) != 0:
                 override += "."
             config_path = f"nginx.{override}config"
-            if not os.path.exists(config_path):
-                config_path = "www/" + config_path
+            if os.path.exists("/nginx-mount/" + config_path):
+                config_path = "/nginx-mount/" + config_path
+            else:
                 if not os.path.exists(config_path):
-                    print("Could not find config file '" + config_path + "'")
-                    return
+                    config_path = "www/" + config_path
+                    if not os.path.exists(config_path):
+                        print("Could not find config file '" + config_path + "'")
+                        return
 
             new_data = open(config_path, "r").read()
             new_data = new_data.replace("{{JAAQL_INSTALL_LOCATION}}", os.environ.get("INSTALL_PATH"))
@@ -1403,6 +1406,16 @@ WHERE
             print(cron_command)
             print("Cron not supported in debugging mode", file=sys.stderr)
 
+    def get_last_successful_build_time(self):
+        if os.environ.get("JAAQL_DEBUGGING") == "TRUE":
+            return jaaql__select(self.jaaql_lookup_connection)[KG__jaaql__last_successful_build_time]
+        else:
+            return 0
+
+    def set_last_successful_build_time(self, http_inputs: dict):
+        if os.environ.get("JAAQL_DEBUGGING") == "TRUE":
+            jaaql__update(self.jaaql_lookup_connection, last_successful_build_time=http_inputs[KG__jaaql__last_successful_build_time])
+
     def submit(self, inputs: dict, account_id: str, verification_hook: Queue = None, as_objects: bool = False, singleton: bool = False):
         return submit(self.vault, self.config, self.get_db_crypt_key(), self.jaaql_lookup_connection, inputs, account_id, verification_hook,
                       self.cached_canned_query_service, as_objects=as_objects, singleton=singleton)
